.elementor-shape{direction:ltr;left:0;line-height:0;overflow:hidden;position:absolute;width:100%}.elementor-shape-top{top:-1px}.elementor-shape-top:not([data-negative=false]) svg{z-index:-1}.elementor-shape-bottom{bottom:-1px}.elementor-shape-bottom:not([data-negative=true]) svg{z-index:-1}.elementor-shape[data-negative=false].elementor-shape-bottom,.elementor-shape[data-negative=true].elementor-shape-top{transform:rotate(180deg)}.elementor-shape svg{display:block;left:50%;position:relative;transform:translateX(-50%);width:calc(100% + 1.3px)}.elementor-shape .elementor-shape-fill{fill:#fff;transform:rotateY(0deg);transform-origin:center}